cal.Room (Room) — amici1

# `cal.Room` (Room)

Room(id, name, company, contact_person, contact_role, display_color, description, name_de, name_fr)

Master tables : cal.AllRooms (Rooms), cal.Rooms (Rooms)

Slave tables : cal.EntriesByRoom (Calendar entries)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Designation (name) : The designation of the room. This is not required to be unique.

- Responsible (company) : Pointer to Company.

- Contact person (contact_person) : Pointer to Person.

- represented as (contact_role) : The optional Role of the contact_person within company.

- Color (display_color) : The color to use when displaying entries in this room in the calendar view.

- Description (description) : See `<lino.core.fields.RichTextField: description>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino_xl.lib.cal.models.Room.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.cal.models.Room.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.cal.models.Room.overview`.

Referenced from cal.Event.room, courses.Course.room

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
name | Designation | The designation of the room. This is not required to be unique.
company | Responsible | Pointer to Company.
contact_person | Contact person | Pointer to Person.
contact_role | represented as | The optional Role of the contact_person within company.
display_color | Color | The color to use when displaying entries in this room in the calendar view.
description | Description |
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |